summaryrefslogtreecommitdiff
path: root/src/theory/arith/callbacks.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/theory/arith/callbacks.h')
-rw-r--r--src/theory/arith/callbacks.h8
1 files changed, 6 insertions, 2 deletions
diff --git a/src/theory/arith/callbacks.h b/src/theory/arith/callbacks.h
index 1ce61f46f..796a93ea4 100644
--- a/src/theory/arith/callbacks.h
+++ b/src/theory/arith/callbacks.h
@@ -19,6 +19,7 @@
#pragma once
#include "expr/node.h"
+#include "expr/proof_node.h"
#include "theory/arith/arithvar.h"
#include "theory/arith/bound_counts.h"
#include "theory/arith/constraint_forward.h"
@@ -177,8 +178,11 @@ private:
public:
RaiseEqualityEngineConflict(TheoryArithPrivate& ta);
- /* If you are not an equality engine, don't use this! */
- void raiseEEConflict(Node n) const;
+ /* If you are not an equality engine, don't use this!
+ *
+ * The proof should prove that `n` is a conflict.
+ * */
+ void raiseEEConflict(Node n, std::shared_ptr<ProofNode> pf) const;
};
class BoundCountingLookup {
generated by cgit on debian on lair
contact matthew@masot.net with questions or feedback